using System;
using System.Collections.Generic;
using System.Text;
using FileHelpers;

namespace GMail2PocketOutlookLib
{
    class GMailCSVReader
    {
        #region Fields

        private FileHelperEngine fileHelperEngine;

        private GMailContact[] gmailContactList;
        private Exception errorCause;

        #endregion

        #region Properties

        /// <summary>
        /// Returns the raw data readed from the CSV
        /// </summary>
        public GMailContact[] GMailContactList
        {
            get
            {
                return gmailContactList;
            }
        }

        /// <summary>
        /// Returns the error cause (if GetData() returns false, check this)
        /// </summary>
        public Exception ErrorCause
        {
            get
            {
                return errorCause;
            }
        }

        #endregion

        #region Class Constructor

        /// <summary>
        /// Class Constructor
        /// </summary>
        public GMailCSVReader()
        {
            fileHelperEngine = new FileHelperEngine(typeof(GMailContact)); 
        }

        #endregion

        #region Public Methods

        /// <summary>
        /// Gets all data and stores it in GMailContactList
        /// </summary>
        /// <param name="Path">Path of the CSV file to use as source for new contacts</param>
        /// <returns>result of the operation</returns>
        public bool GetData(string Path)
        {
            if (string.IsNullOrEmpty(Path))
            {
                return false;
            }

            try
            {
                gmailContactList = fileHelperEngine.ReadFile(Path) as GMailContact[];
            }
            catch (Exception ex)
            {
                errorCause = ex;
                return false;
            }
            
            return true;
        }

        #endregion
    }
}
