using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using GMail2PocketOutlookLib;

namespace GmailContactsImport
{
    /// <summary>
    /// Main application form
    /// </summary>
    public partial class MainForm : Form
    {
        #region Fields

        private Importer gmailImporter = null;

        #endregion

        #region Class Constructor

        /// <summary>
        /// Class Constructor
        /// </summary>
        public MainForm()
        {
            InitializeComponent();
        }

        #endregion

        #region Event Handlers

        /// <summary>
        /// Creates objects and setups options
        /// </summary>
        /// <param name="sender">Sender</param>
        /// <param name="e">Event Arguments</param>
        private void MainForm_Load(object sender, EventArgs e)
        {
            gmailImporter = new Importer();
        }

        /// <summary>
        /// Loads data and prepares for the import process
        /// </summary>
        /// <param name="sender">Sender</param>
        /// <param name="e">Event Arguments</param>
        private void getDataButton_Click(object sender, EventArgs e)
        {
            bool result;

            if (string.IsNullOrEmpty(csvFilePathTextBox.Text))
            {
                statusLabel.Text = "Path cannot be empty";
                return;
            }

            result = gmailImporter.GetData(csvFilePathTextBox.Text);

            if (result)
            {
                existingContactsCountTextBox.Text = gmailImporter.ExistingContactsCount.ToString();
                newContactsCountTextBox.Text = gmailImporter.NewContactsCount.ToString();

                statusLabel.Text = "Data ready to import";

                importDataButton.Enabled = true;
                deleteExistingDataButton.Enabled = true;
                getDataButton.Enabled = false;
            }
            else
            {
                statusLabel.Text = "Error getting data";
            }
        }

        /// <summary>
        /// Imports gathered data
        /// </summary>
        /// <param name="sender">Sender</param>
        /// <param name="e">Event Arguments</param>
        private void importDataButton_Click(object sender, EventArgs e)
        {
            bool result;

            result = gmailImporter.ImportData();

            if (result)
            {
                existingContactsCountTextBox.Text = gmailImporter.ExistingContactsCount.ToString();

                statusLabel.Text = "Successfully imported";
                //this.Close();
            }
            else
            {
                statusLabel.Text = "Error importing data";
            }
        }

        /// <summary>
        /// Deletes existing data
        /// </summary>
        /// <param name="sender">Sender</param>
        /// <param name="e">Event Arguments</param>
        private void deleteExistingDataButton_Click(object sender, EventArgs e)
        {
            bool result;

            result = gmailImporter.DeleteExistingData();

            if (result)
            {
                existingContactsCountTextBox.Text = gmailImporter.ExistingContactsCount.ToString();

                statusLabel.Text = "Deleted existing data";
            }
            else
            {
                statusLabel.Text = "Error deleting data";
            }
        }

        #endregion
    }
}